/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.netbeans.modules.websvc.wsitmodelext.versioning;

import org.netbeans.modules.websvc.wsstack.api.WSStackVersion;
import org.openide.util.NbBundle;

public enum ConfigVersion {
    CONFIG_1_0 {
        public final boolean isSupported(WSStackVersion jaxWsVersion) {
            return true;
        }
    },
    CONFIG_1_3 {
        public final boolean isSupported(WSStackVersion jaxWsVersion) {
            if (jaxWsVersion.compareTo(WSStackVersion.valueOf(2, 1, 4, 1)) >= 0) {
                return true;
            }
            return false;
        }
    },
    CONFIG_2_0 {
        public final boolean isSupported(WSStackVersion jaxWsVersion) {
            if (jaxWsVersion.compareTo(WSStackVersion.valueOf(2, 2, 0, 0)) >= 0) {
                return true;
            }
            return false;
        }
        @Override
        public boolean isVisible() {
            return false;
        }
    };

    @Override
    public String toString() {
        return NbBundle.getMessage(ConfigVersion.class, this.name());
    }
    
    public final static ConfigVersion getDefault() {
        return CONFIG_2_0;
    }

    public abstract boolean isSupported(WSStackVersion jaxWsVersion);

    public boolean isVisible() {
        return true;
    }
}
