/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.nativeexecution.support;

import java.util.ArrayList;
import java.util.List;

/**
 */
public final class TerminalProfile {
    private String command;
    private List<String> arguments = new ArrayList<>();
    private List<String> searchPaths = new ArrayList<>();
    private List<String> validationCommands = new ArrayList<>();
    private String id;
    private String platforms;

    public TerminalProfile() {
    }

    public void addArgument(String arg) {
        this.arguments.add(arg);
    }

    public void addValidationCommand(String command) {
        validationCommands.add(command);
    }

    public List<String> getValidationCommands() {
        return validationCommands;
    }

    public String getID() {
        return id;
    }

    public void setCommand(String command) {
        this.command = command.trim();
    }

    public void setID(String id) {
        this.id = id;
    }

    public void setSupportedPlatforms(String platforms) {
        this.platforms = platforms;
    }

    public String getCommand() {
        return command;
    }

    public void addSearchPath(String path) {
        searchPaths.add(path);
    }

    public List<String> getSearchPaths() {
        return searchPaths;
    }

    public List<String> getArguments() {
        return arguments;
    }
}
