/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.netbeans.modules.parsing.spi;

/**
 * A service providing information about
 * low memory condition.
 *
 * @since 1.2
 * @author Tomas Zezula
 */
public final class LowMemoryWatcher {

    //@GuardedBy("LowMemoryWatcher.class")
    private static LowMemoryWatcher instance;

    private final org.netbeans.modules.parsing.lucene.support.LowMemoryWatcher delegate;

    private LowMemoryWatcher () {
        this.delegate = org.netbeans.modules.parsing.lucene.support.LowMemoryWatcher.getInstance();
    }

    /**
     * Returns true if the application is in low memory condition.
     * This information can be used by batch file processing.
     * @return true if nearly whole memory is used
     */
    public boolean isLowMemory () {
        return delegate.isLowMemory();
    }

    /**
     * Tries to free memory.
     * @since 2.12
     */
    public void free() {
        delegate.free();
    }

    /**
     * Returns an instance of {@link LowMemoryWatcher}
     * @return the {@link LowMemoryWatcher}
     */
    public static synchronized LowMemoryWatcher getInstance() {
        if (instance == null) {
            instance = new LowMemoryWatcher();
        }
        return instance;
    }
}
