/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.netbeans.modules.xml.wsdl.model.extensions.mime.impl;

import org.netbeans.modules.xml.wsdl.model.BindingInput;
import org.netbeans.modules.xml.wsdl.model.BindingOutput;
import org.netbeans.modules.xml.wsdl.model.Part;
import org.netbeans.modules.xml.wsdl.model.WSDLModel;
import org.netbeans.modules.xml.wsdl.model.extensions.mime.MIMEComponent;
import org.netbeans.modules.xml.wsdl.model.extensions.mime.MIMEContent;
import org.netbeans.modules.xml.wsdl.model.extensions.mime.MIMEQName;
import org.netbeans.modules.xml.wsdl.model.impl.WSDLAttribute;
import org.netbeans.modules.xml.xam.Component;
import org.netbeans.modules.xml.xam.Reference;
import org.w3c.dom.Element;

/**
 *
 * @author jyang
 */
public class MIMEContentImpl extends MIMEComponentImpl implements MIMEContent {

    /** Creates a new instance of MIMEContentImpl */
    public MIMEContentImpl(WSDLModel model, Element e) {
        super(model, e);
    }

    public MIMEContentImpl(WSDLModel model) {
        this(model, createPrefixedElement(MIMEQName.CONTENT.getQName(), model));
    }

    /**
     * Set the part for this MIME content.
     *
     * @param part the desired part
     */
    public void setPart(String part) {
        setAttribute(PART_PROPERTY, MIMEAttribute.PART, part);
    }

    /**
     * Get the part for this MIME content.
     */
    public String getPart() {
        return getAttribute(MIMEAttribute.PART);
    }

    /**
     * Set the type for this MIME content.
     *
     * @param type the desired type
     */
    public void setType(String type) {
        setAttribute(PART_PROPERTY, WSDLAttribute.TYPE, type);
    }

    /**
     * Get the type for this MIME content.
     */
    public String getType() {
        return getAttribute(WSDLAttribute.TYPE);
    }

    @Override
    public boolean canBeAddedTo(Component target) {
        if (target instanceof BindingInput || target instanceof BindingOutput) {
            return true;
        }
        return false;
    }

    public void accept(MIMEComponent.Visitor visitor) {
        visitor.visit(this);
    }

    public Reference<Part> getPartRef() {
        String v = getPart();
        return v == null ? null : new PartReference(this, v);
    }

    public void setTypeRef(Reference<Part> partRef) {
        String v = partRef == null ? null : partRef.getRefString();
        setAttribute(PART_PROPERTY, MIMEAttribute.PART, v);
    }
}
