/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.netbeans.modules.projectimport.eclipse.gui;

import java.io.File;
import org.netbeans.jellytools.Bundle;
import org.netbeans.jellytools.NbDialogOperator;
import org.netbeans.jellytools.WizardOperator;
import org.netbeans.jemmy.operators.JRadioButtonOperator;
import org.netbeans.jemmy.operators.JTextFieldOperator;

/**
 *
 * @author mkhramov@netbeans.org
 */
public class ImportStandaloneProject extends ProjectImporterTestCase {

    WizardOperator importWizard;
    String projectName = "AloneJP";
    public ImportStandaloneProject(String testName) {
        super(testName);
    }
    @Override
    public void setUp() throws Exception {
        super.setUp();
        ExtractToWorkDir(getDataDir(), "testdata.jar");
    }

    public void testImportStandaloneProject() {

        importWizard = invokeImporterWizard();

        selectSingleProject(importWizard,"sta", projectName);
        importWizard.finish();

        waitForProjectsImporting();

        try {
            NbDialogOperator issuesWindow = new NbDialogOperator(Bundle.getStringTrimmed("org.netbeans.modules.projectimport.eclipse.core.Bundle", "MSG_ImportIssues"));
            issuesWindow.close();
        } catch (Exception e) {
            // ignore
        }

        validateProjectRootNode(projectName);
        validateProjectTestLibNode(projectName);
        validateProjectSrcNode(projectName,"src");
        validateProjectTestNode(projectName, "test");
    }

    protected void selectSingleProject(WizardOperator wizz, String workspace, String prjName) {
        JRadioButtonOperator importMode = new JRadioButtonOperator(wizz, 1);
        importMode.pushNoBlock();
        JTextFieldOperator txtProjectLocation = new JTextFieldOperator(wizz, 1);
        JTextFieldOperator txtImportLocation = new JTextFieldOperator(wizz, 2);
        String projectPath = getDataDir().getAbsolutePath() + File.separatorChar + workspace+ File.separatorChar +prjName;
	log("Project Path = "+projectPath);
        txtProjectLocation.setText(projectPath);
        txtImportLocation.setText(projectPath);

    }
}
