/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.php.dbgp.models.nodes;

import java.util.Set;

import org.netbeans.modules.php.dbgp.models.VariablesModelFilter.FilterType;
import org.netbeans.modules.php.dbgp.packets.Property;
import org.openide.util.NbBundle;

/**
 * @author ads
 *
 */
class ObjectVariableNode extends org.netbeans.modules.php.dbgp.models.VariablesModel.AbstractVariableNode {
    protected static final String OBJECT_ICON = "org/netbeans/modules/debugger/resources/localsView/LocalVariablesGroup"; //NOI18N
    private static final String TYPE_OBJECT = "TYPE_Object"; // NOI18N
    private static final String THIS = "$this"; // NOI18N
    private static final String SELF = "self"; // NOI18N

    ObjectVariableNode(Property property, AbstractModelNode parent) {
        super(property, parent);
    }

    @Override
    public String getType() {
        String className = getProperty().getClassName();
        return (className != null && !className.isEmpty()) ? className : NbBundle.getMessage(ObjectVariableNode.class, TYPE_OBJECT);
    }

    @Override
    public String getIconBase() {
        String name = getProperty().getName();
        if (THIS.equals(name) || SELF.equals(name)) {
            return FIELD_ICON;
        }
        return OBJECT_ICON;
    }

    @Override
    protected boolean isTypeApplied(Set<FilterType> filters) {
        return filters.contains(FilterType.OBJECT);
    }

}
